PackageError

Enum PackageError 

pub enum PackageError {
Show 15 variants ManifestNotFound { path: String, }, ParseError(Error), Io(Error), BuildFailed(String), SignatureNotFound { path: String, }, SignatureInvalid { path: String, }, ArchiveError(String), InvalidArchive(String), InvalidManifest(String), PathTraversal { entry: String, }, AbsolutePath { entry: String, }, SymlinkRejected { entry: String, }, HardlinkRejected { entry: String, }, SizeLimitExceeded { limit: u64, actual: u64, }, TooManyEntries { limit: u32, },
}
Errors that can occur when loading a package manifest.

Variants



ManifestNotFound

The package.toml file was not found in the given directory.

Fields

path: String


ParseError(Error)

The manifest file could not be parsed as valid TOML or failed schema validation (the [metadata] section didn’t match M).



Io(Error)

An I/O error occurred reading the manifest file.



BuildFailed(String)

Build failed.



SignatureNotFound

Package signature file not found.

Fields

path: String


SignatureInvalid

Package signature is invalid (no trusted key verified it).

Fields

path: String


ArchiveError(String)

An error occurred creating or reading an archive.



InvalidArchive(String)

The archive does not contain a valid package.



InvalidManifest(String)

Manifest passed serde parsing but failed cross-section validation (e.g. runtime = "python" without a [python] section, or unknown runtime value).



PathTraversal

Archive entry contains a .. component that would escape dest.

Fields

entry: String


AbsolutePath

Archive entry has an absolute path (root or drive prefix).

Fields

entry: String


SymlinkRejected

Archive contains a symlink entry, which could be used to overwrite arbitrary files outside dest on a follow-up write.

Fields

entry: String


HardlinkRejected

Archive contains a hardlink entry, same threat model as symlinks.

Fields

entry: String


SizeLimitExceeded

Cumulative decompressed size exceeded the configured cap.

Fields

limit: u64
actual: u64


TooManyEntries

Archive contains more entries than the configured cap allows.

Fields

limit: u32