pub fn deserialize<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, WireError>Expand description
Deserialize a value from the active wire format.
Expects JSON bytes in debug builds, bincode bytes in release builds.
pub fn deserialize<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, WireError>Deserialize a value from the active wire format.
Expects JSON bytes in debug builds, bincode bytes in release builds.