pub enum PackageError {
ManifestNotFound {
path: String,
},
ParseError(Error),
Io(Error),
BuildFailed(String),
SignatureNotFound {
path: String,
},
SignatureInvalid {
path: String,
},
}Expand description
Errors that can occur when loading a package manifest.
Variants
ManifestNotFound
The package.toml file was not found in the given directory.
ParseError(Error)
The manifest file could not be parsed as valid TOML or failed
schema validation (the [metadata] section didn’t match M).
Io(Error)
An I/O error occurred reading the manifest file.
BuildFailed(String)
Build failed.
SignatureNotFound
Package signature file not found.
SignatureInvalid
Package signature is invalid (no trusted key verified it).